/*
 * SonarQube
 * Copyright (C) 2009-2016 SonarSource SA
 * mailto:contact AT sonarsource DOT com
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
package org.sonar.db.version.v62;

import java.sql.SQLException;
import org.sonar.db.Database;
import org.sonar.db.version.BaseDataChange;
import org.sonar.db.version.MassUpdate;

public class DeletePermissionShareDashboard extends BaseDataChange {

  private static final String PERMISSION = "shareDashboard";

  public DeletePermissionShareDashboard(Database db) {
    super(db);
  }

  @Override
  public void execute(Context context) throws SQLException {
    deleteFromTable(context, "group_roles");
    deleteFromTable(context, "user_roles");
  }

  private static void deleteFromTable(Context context, String tableName) throws SQLException {
    MassUpdate massUpdate = context.prepareMassUpdate();
    massUpdate.select("select id from " + tableName + " where role=?").setString(1, PERMISSION);
    massUpdate.update("delete from " + tableName + " where id=?");
    massUpdate.rowPluralName(tableName);
    massUpdate.execute((row, update) -> {
      update.setLong(1, row.getLong(1));
      return true;
    });
  }
}
